@@ -205,7 +205,7 @@ class cache_definition {
 
     /**
      * Gets set to true if this definition requires searchable stores.
-     * @since 2.4.4
+     * @since Moodle 2.4.4
      * @var bool
      */
     protected $requiresearchable = false;
@@ -242,7 +242,8 @@ class cache_definition {
     protected $datasourcefile = null;
 
     /**
-     * The data source class aggregate to use. This is a super advanced setting.
+     * Deprecated - this is completely unused.
+     * @deprecated since 2.9
      * @var string
      */
     protected $datasourceaggregate = null;
@@ -281,7 +282,7 @@ class cache_definition {
      * An array of identifiers provided to this cache when it was initialised.
      * @var array
      */
-    protected $identifiers = array();
+    protected $identifiers = null;
 
     /**
      * Key prefix for use with single key cache stores
@@ -324,11 +325,11 @@ class cache_definition {
      *
      * @param string $id
      * @param array $definition
-     * @param string $datasourceaggregate
+     * @param string $unused Used to be datasourceaggregate but that was removed and this is now unused.
      * @return cache_definition
      * @throws coding_exception
      */
-    public static function load($id, array $definition, $datasourceaggregate = null) {
+    public static function load($id, array $definition, $unused = null) {
         global $CFG;
 
         if (!array_key_exists('mode', $definition)) {
@@ -520,7 +521,6 @@ class cache_definition {
         $cachedefinition->overrideclassfile = $overrideclassfile;
         $cachedefinition->datasource = $datasource;
         $cachedefinition->datasourcefile = $datasourcefile;
-        $cachedefinition->datasourceaggregate = $datasourceaggregate;
         $cachedefinition->staticacceleration = $staticacceleration;
         $cachedefinition->staticaccelerationsize = $staticaccelerationsize;
         $cachedefinition->ttl = $ttl;
@@ -654,6 +654,9 @@ class cache_definition {
      * @return array
      */
     public function get_identifiers() {
+        if (!isset($this->identifiers)) {
+            return array();
+        }
         return $this->identifiers;
     }
 
@@ -731,7 +734,7 @@ class cache_definition {
 
     /**
      * Returns true if this definition requires a searchable cache.
-     * @since 2.4.4
+     * @since Moodle 2.4.4
      * @return bool
      */
     public function require_searchable() {
@@ -766,11 +769,20 @@ class cache_definition {
      * @throws coding_exception
      */
     public function set_identifiers(array $identifiers = array()) {
+        // If we are setting the exact same identifiers then just return as nothing really changed.
+        // We don't care about order as cache::make will use the same definition order all the time.
+        if ($identifiers === $this->identifiers) {
+            return;
+        }
+
         foreach ($this->requireidentifiers as $identifier) {
             if (!isset($identifiers[$identifier])) {
                 throw new coding_exception('Identifier required for cache has not been provided: '.$identifier);
             }
         }
+
+        $this->identifiers = array();
+
         foreach ($identifiers as $name => $value) {
             $this->identifiers[$name] = (string)$value;
         }
@@ -893,7 +905,7 @@ class cache_definition {
                 'area' => $this->area,
                 'siteidentifier' => $this->get_cache_identifier()
             );
-            if (!empty($this->identifiers)) {
+            if (isset($this->identifiers) && !empty($this->identifiers)) {
                 $identifiers = array();
                 foreach ($this->identifiers as $key => $value) {
                     $identifiers[] = htmlentities($key, ENT_QUOTES, 'UTF-8').'='.htmlentities($value, ENT_QUOTES, 'UTF-8');
@@ -963,4 +975,31 @@ class cache_definition {
     public function has_required_identifiers() {
         return (count($this->requireidentifiers) > 0);
     }
+
+    /**
+     * Returns the possible sharing options that can be used with this defintion.
+     *
+     * @return int
+     */
+    public function get_sharing_options() {
+        return $this->sharingoptions;
+    }
+
+    /**
+     * Returns the user entered sharing key for this definition.
+     *
+     * @return string
+     */
+    public function get_user_input_sharing_key() {
+        return $this->userinputsharingkey;
+    }
+
+    /**
+     * Returns the user selected sharing option for this definition.
+     *
+     * @return int
+     */
+    public function get_selected_sharing_option() {
+        return $this->selectedsharingoption;
+    }
 }
