@@ -667,7 +667,7 @@ class mod_scorm_external extends external_api {
                 $module['course'] = $scorm->course;
                 $module['name']  = external_format_string($scorm->name, $context->id);
                 list($module['intro'], $module['introformat']) =
-                    external_format_text($scorm->intro, $scorm->introformat, $context->id, 'mod_scorm', 'intro', $scorm->id);
+                    external_format_text($scorm->intro, $scorm->introformat, $context->id, 'mod_scorm', 'intro', null);
 
                 // Check if the SCORM open and return warnings if so.
                 list($open, $openwarnings) = scorm_get_availability_status($scorm, true, $context);
@@ -758,16 +758,17 @@ class mod_scorm_external extends external_api {
                                                                     VALUE_OPTIONAL),
                             'lastattemptlock' => new external_value(PARAM_BOOL, 'Prevents to launch new attempts once finished',
                                                                     VALUE_OPTIONAL),
-                            'displayattemptstatus' => new external_value(PARAM_BOOL, 'Display attempts status', VALUE_OPTIONAL),
+                            'displayattemptstatus' => new external_value(PARAM_INT, 'How to display attempt status',
+                                                                            VALUE_OPTIONAL),
                             'displaycoursestructure' => new external_value(PARAM_BOOL, 'Display contents structure',
                                                                             VALUE_OPTIONAL),
                             'sha1hash' => new external_value(PARAM_NOTAGS, 'Package content or ext path hash', VALUE_OPTIONAL),
                             'md5hash' => new external_value(PARAM_NOTAGS, 'MD5 Hash of package file', VALUE_OPTIONAL),
                             'revision' => new external_value(PARAM_INT, 'Revison number', VALUE_OPTIONAL),
                             'launch' => new external_value(PARAM_INT, 'First content to launch', VALUE_OPTIONAL),
-                            'skipview' => new external_value(PARAM_BOOL, 'Skip or not content structure page', VALUE_OPTIONAL),
+                            'skipview' => new external_value(PARAM_INT, 'How to skip the content structure page', VALUE_OPTIONAL),
                             'hidebrowse' => new external_value(PARAM_BOOL, 'Disable preview mode?', VALUE_OPTIONAL),
-                            'hidetoc' => new external_value(PARAM_BOOL, 'Display or not course structure in player',
+                            'hidetoc' => new external_value(PARAM_INT, 'How to display the SCORM structure in player',
                                                             VALUE_OPTIONAL),
                             'nav' => new external_value(PARAM_INT, 'Show navigation buttons', VALUE_OPTIONAL),
                             'navpositionleft' => new external_value(PARAM_INT, 'Navigation position left', VALUE_OPTIONAL),
