@@ -156,13 +156,16 @@ M.mod_scorm.init = function(Y, nav_display, navposition_left, navposition_top, h
             var obj = document.createElement('iframe');
             obj.setAttribute('id', 'scorm_object');
             obj.setAttribute('type', 'text/html');
+            obj.setAttribute('allowfullscreen', 'allowfullscreen');
+            obj.setAttribute('webkitallowfullscreen', 'webkitallowfullscreen');
+            obj.setAttribute('mozallowfullscreen', 'mozallowfullscreen');
             if (!window_name && node.title != null) {
                 obj.setAttribute('src', url_prefix + node.title);
             }
             if (window_name) {
                 var mine = window.open('','','width=1,height=1,left=0,top=0,scrollbars=no');
                 if(! mine) {
-                    alert(M.str.scorm.popupsblocked);
+                    alert(M.util.get_string('popupsblocked', 'scorm'));
                 }
                 mine.close();
             }
@@ -295,9 +298,11 @@ M.mod_scorm.init = function(Y, nav_display, navposition_left, navposition_top, h
             }
 
             // Calculate the rough new height from the viewport height.
-            newheight = Y.one('body').get('winHeight') - 5;
-            if (newheight < 600) {
-                newheight = 600;
+            var newheight = Y.one('body').get('winHeight') - 5
+                - Y.one('#scorm_layout').getY()
+                - window.pageYOffset;
+            if (newheight < 680 || isNaN(newheight)) {
+                newheight = 680;
             }
             Y.one('#scorm_layout').setStyle('height', newheight);
 
@@ -802,6 +807,9 @@ M.mod_scorm.connectPrereqCallback = {
             }
             var el_new_tree = document.createElement('div');
             var pagecontent = document.getElementById("page-content");
+            if (!pagecontent) {
+                pagecontent = document.getElementById("content");
+            }
             el_new_tree.setAttribute('id','scormtree123');
             el_new_tree.innerHTML = o.responseText;
             // Make sure it does not show.
