@@ -75,7 +75,7 @@ class mod_workshop_mod_form extends moodleform_mod {
         $mform->addRule('name', get_string('maximumchars', '', 255), 'maxlength', 255, 'client');
 
         // Introduction
-        $this->add_intro_editor(false, get_string('introduction', 'workshop'));
+        $this->standard_intro_elements(get_string('introduction', 'workshop'));
 
         // Grading settings -----------------------------------------------------------
         $mform->addElement('header', 'gradingsettings', get_string('gradingsettings', 'workshop'));
@@ -97,6 +97,11 @@ class mod_workshop_mod_form extends moodleform_mod {
         $mform->setDefault('grade', $workshopconfig->grade);
         $mform->addHelpButton('submissiongradegroup', 'submissiongrade', 'workshop');
 
+        $mform->addElement('text', 'submissiongradepass', get_string('gradetopasssubmission', 'workshop'));
+        $mform->addHelpButton('submissiongradepass', 'gradepass', 'grades');
+        $mform->setDefault('submissiongradepass', '');
+        $mform->setType('submissiongradepass', PARAM_RAW);
+
         $label = get_string('gradinggrade', 'workshop');
         $mform->addGroup(array(
             $mform->createElement('select', 'gradinggrade', '', $grades),
@@ -105,6 +110,11 @@ class mod_workshop_mod_form extends moodleform_mod {
         $mform->setDefault('gradinggrade', $workshopconfig->gradinggrade);
         $mform->addHelpButton('gradinggradegroup', 'gradinggrade', 'workshop');
 
+        $mform->addElement('text', 'gradinggradepass', get_string('gradetopassgrading', 'workshop'));
+        $mform->addHelpButton('gradinggradepass', 'gradepass', 'grades');
+        $mform->setDefault('gradinggradepass', '');
+        $mform->setType('gradinggradepass', PARAM_RAW);
+
         $options = array();
         for ($i=5; $i>=0; $i--) {
             $options[$i] = $i;
@@ -216,7 +226,7 @@ class mod_workshop_mod_form extends moodleform_mod {
         plagiarism_get_form_elements_module($mform, $coursecontext, 'mod_workshop');
 
         // Common module settings, Restrict availability, Activity completion etc. ----
-        $features = array('groups'=>true, 'groupings'=>true, 'groupmembersonly'=>true,
+        $features = array('groups' => true, 'groupings' => true,
                 'outcomes'=>true, 'gradecat'=>false, 'idnumber'=>false);
 
         $this->standard_coursemodule_elements();
@@ -296,7 +306,10 @@ class mod_workshop_mod_form extends moodleform_mod {
                 foreach ($gradeitems as $gradeitem) {
                     // here comes really crappy way how to set the value of the fields
                     // gradecategory and gradinggradecategory - grrr QuickForms
+                    $decimalpoints = $gradeitem->get_decimals();
                     if ($gradeitem->itemnumber == 0) {
+                        $submissiongradepass = $mform->getElement('submissiongradepass');
+                        $submissiongradepass->setValue(format_float($gradeitem->gradepass, $decimalpoints));
                         $group = $mform->getElement('submissiongradegroup');
                         $elements = $group->getElements();
                         foreach ($elements as $element) {
@@ -305,6 +318,8 @@ class mod_workshop_mod_form extends moodleform_mod {
                             }
                         }
                     } else if ($gradeitem->itemnumber == 1) {
+                        $gradinggradepass = $mform->getElement('gradinggradepass');
+                        $gradinggradepass->setValue(format_float($gradeitem->gradepass, $decimalpoints));
                         $group = $mform->getElement('gradinggradegroup');
                         $elements = $group->getElements();
                         foreach ($elements as $element) {
@@ -328,7 +343,7 @@ class mod_workshop_mod_form extends moodleform_mod {
      * @return array eventual errors indexed by the field name
      */
     public function validation($data, $files) {
-        $errors = array();
+        $errors = parent::validation($data, $files);
 
         // check the phases borders are valid
         if ($data['submissionstart'] > 0 and $data['submissionend'] > 0 and $data['submissionstart'] >= $data['submissionend']) {
@@ -355,6 +370,30 @@ class mod_workshop_mod_form extends moodleform_mod {
             }
         }
 
+        // Check that the submission grade pass is a valid number.
+        if (!empty($data['submissiongradepass'])) {
+            $submissiongradefloat = unformat_float($data['submissiongradepass'], true);
+            if ($submissiongradefloat === false) {
+                $errors['submissiongradepass'] = get_string('err_numeric', 'form');
+            } else {
+                if ($submissiongradefloat > $data['grade']) {
+                    $errors['submissiongradepass'] = get_string('gradepassgreaterthangrade', 'grades', $data['grade']);
+                }
+            }
+        }
+
+        // Check that the grade pass is a valid number.
+        if (!empty($data['gradinggradepass'])) {
+            $gradepassfloat = unformat_float($data['gradinggradepass'], true);
+            if ($gradepassfloat === false) {
+                $errors['gradinggradepass'] = get_string('err_numeric', 'form');
+            } else {
+                if ($gradepassfloat > $data['gradinggrade']) {
+                    $errors['gradinggradepass'] = get_string('gradepassgreaterthangrade', 'grades', $data['gradinggrade']);
+                }
+            }
+        }
+
         return $errors;
     }
 }
